==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/ar.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "متوسط الحمل",
    "Last minute" : "اخر دقيقة",
    "Memory info not available" : "معلومات الذاكرة غير متوفرة",
    "Total" : "المجموع",
    "Current usage" : "الاستخدام الحالي",
    "Users" : "المستخدمين:",
    "Groups" : "المجموعات:",
    "Links" : "الروابط",
    "Mails" : "الرسائل",
    "24 hours" : "24 ساعة",
    "1 hour" : "ساعة",
    "5 mins" : "5 دقائق",
    "Copy" : "نسخ",
    "Copied!" : "تم نسخه !",
    "System" : "النظام",
    "Monitoring" : "المراقبة",
    "Operating System" : "نظام التشغيل",
    "CPU" : "وحدة المعالجة المركزية",
    "Memory" : "الذاكرة",
    "Server time" : "الوقت على الخادم",
    "Filesystem" : "نظام الملفات",
    "Size" : "الحجم",
    "Available" : "متوفرة",
    "Used" : "مستعمَلة",
    "Files:" : "الملفات:",
    "Free Space:" : "المساحة الحرة:",
    "Network" : "الشبكة",
    "Hostname" : "اسم المضيف",
    "DNS" : "نظام أسماء النطاقات",
    "Gateway" : "البوابة",
    "Status" : "الحالة",
    "Speed" : "السرعة",
    "Active users" : "المستخدمون النشطون",
    "Total users:" : "العدد الإجمالي للمستخدمين:",
    "Shares" : "مشاركة",
    "PHP" : "PHP",
    "Version:" : "الأصدار:",
    "Memory Limit:" : "حد الذاكرة:",
    "Max Execution Time:" : "مدة أقصى إجراء",
    "Upload max size:" : "الحجم الأقصى للرفع:",
    "Database" : "قاعدة البيانات",
    "Type:" : "النوع:",
    "Size:" : "الحجم:",
    "Did you know?" : "هل تعلم؟",
    "Last 24 hours" : "اخر 24 ساعة",
    "Last 1 hour" : "اخر 1 ساعة",
    "Last 5 mins" : "اخر 5 دقائق",
    "CPU load" : "حمل المعالج",
    "Memory usage" : "المستخدام من الذاكرة",
    "Storage" : "تخزين",
    "Users:" : "المستخدمين:",
    "Nextcloud" : "Nextcloud",
    "Apps installed:" : "التطبيقات المثبتة:",
    "Apps updates available:" : "التحديثات المتوفرة للتطبيقات:"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-19.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/ar.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "متوسط الحمل",
    "Last minute" : "اخر دقيقة",
    "Memory info not available" : "معلومات الذاكرة غير متوفرة",
    "Total" : "المجموع",
    "Current usage" : "الاستخدام الحالي",
    "Users" : "المستخدمين:",
    "Groups" : "المجموعات:",
    "Links" : "الروابط",
    "Mails" : "الرسائل",
    "24 hours" : "24 ساعة",
    "1 hour" : "ساعة",
    "5 mins" : "5 دقائق",
    "Copy" : "نسخ",
    "Copied!" : "تم نسخه !",
    "Not supported!" : "غير مدعوم!",
    "Press ⌘-C to copy." : "إضغط ⌘-C للنسخ",
    "Press Ctrl-C to copy." : "إضغط Ctrl-C للنسخ.",
    "System" : "النظام",
    "Monitoring" : "المراقبة",
    "Operating System" : "نظام التشغيل",
    "CPU" : "وحدة المعالجة المركزية",
    "Memory" : "الذاكرة",
    "Server time" : "الوقت على الخادم",
    "Filesystem" : "نظام الملفات",
    "Size" : "الحجم",
    "Available" : "متوفرة",
    "Used" : "مستعمَلة",
    "Files:" : "الملفات:",
    "Free Space:" : "المساحة الحرة:",
    "Network" : "الشبكة",
    "Hostname" : "اسم المضيف",
    "DNS" : "نظام أسماء النطاقات",
    "Gateway" : "البوابة",
    "Status" : "الحالة",
    "Speed" : "السرعة",
    "Active users" : "المستخدمون النشطون",
    "Total users:" : "العدد الإجمالي للمستخدمين:",
    "Shares" : "مشاركة",
    "PHP" : "PHP",
    "Version:" : "الأصدار:",
    "Memory Limit:" : "حد الذاكرة:",
    "Max Execution Time:" : "مدة أقصى إجراء",
    "Upload max size:" : "الحجم الأقصى للرفع:",
    "Database" : "قاعدة البيانات",
    "Type:" : "النوع:",
    "Size:" : "الحجم:",
    "Last 24 hours" : "اخر 24 ساعة",
    "Last 1 hour" : "اخر 1 ساعة",
    "Last 5 mins" : "اخر 5 دقائق",
    "CPU load" : "حمل المعالج",
    "Memory usage" : "المستخدام من الذاكرة",
    "Storage" : "تخزين",
    "Users:" : "المستخدمين:",
    "Nextcloud" : "Nextcloud",
    "Apps installed:" : "التطبيقات المثبتة:",
    "Apps updates available:" : "التحديثات المتوفرة للتطبيقات:",
    "Did you know?" : "هل تعلم؟"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
